==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/labservices/kotlin/inputs/LabNetworkProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.labservices.kotlin.inputs

import com.pulumi.azurenative.labservices.inputs.LabNetworkProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Profile for how to handle networking for Labs.
 * @property loadBalancerId The external load balancer resource id
 * @property publicIpId The external public IP resource id
 * @property subnetId The external subnet resource id
 */
public data class LabNetworkProfileArgs(
    public val loadBalancerId: Output<String>? = null,
    public val publicIpId: Output<String>? = null,
    public val subnetId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.labservices.inputs.LabNetworkProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.labservices.inputs.LabNetworkProfileArgs =
        com.pulumi.azurenative.labservices.inputs.LabNetworkProfileArgs.builder()
            .loadBalancerId(loadBalancerId?.applyValue({ args0 -> args0 }))
            .publicIpId(publicIpId?.applyValue({ args0 -> args0 }))
            .subnetId(subnetId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LabNetworkProfileArgs].
 */
@PulumiTagMarker
public class LabNetworkProfileArgsBuilder internal constructor() {
    private var loadBalancerId: Output<String>? = null

    private var publicIpId: Output<String>? = null

    private var subnetId: Output<String>? = null

    /**
     * @param value The external load balancer resource id
     */
    @JvmName("iqxwabbwqefxsrtt")
    public suspend fun loadBalancerId(`value`: Output<String>) {
        this.loadBalancerId = value
    }

    /**
     * @param value The external public IP resource id
     */
    @JvmName("nfpqymryagiasfvw")
    public suspend fun publicIpId(`value`: Output<String>) {
        this.publicIpId = value
    }

    /**
     * @param value The external subnet resource id
     */
    @JvmName("difgpgqcklocjspt")
    public suspend fun subnetId(`value`: Output<String>) {
        this.subnetId = value
    }

    /**
     * @param value The external load balancer resource id
     */
    @JvmName("jjejoqcdjyoxgbuo")
    public suspend fun loadBalancerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadBalancerId = mapped
    }

    /**
     * @param value The external public IP resource id
     */
    @JvmName("fsjrknipargnqddu")
    public suspend fun publicIpId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicIpId = mapped
    }

    /**
     * @param value The external subnet resource id
     */
    @JvmName("guorfbyxensdstwo")
    public suspend fun subnetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnetId = mapped
    }

    internal fun build(): LabNetworkProfileArgs = LabNetworkProfileArgs(
        loadBalancerId = loadBalancerId,
        publicIpId = publicIpId,
        subnetId = subnetId,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/labservices/kotlin/inputs/LabNetworkProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.labservices.kotlin.inputs

import com.pulumi.azurenative.labservices.inputs.LabNetworkProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Profile for how to handle networking for Labs.
 * @property loadBalancerId The external load balancer resource id
 * @property publicIpId The external public IP resource id
 * @property subnetId The external subnet resource id
 */
public data class LabNetworkProfileArgs(
    public val loadBalancerId: Output<String>? = null,
    public val publicIpId: Output<String>? = null,
    public val subnetId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.labservices.inputs.LabNetworkProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.labservices.inputs.LabNetworkProfileArgs =
        com.pulumi.azurenative.labservices.inputs.LabNetworkProfileArgs.builder()
            .loadBalancerId(loadBalancerId?.applyValue({ args0 -> args0 }))
            .publicIpId(publicIpId?.applyValue({ args0 -> args0 }))
            .subnetId(subnetId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LabNetworkProfileArgs].
 */
@PulumiTagMarker
public class LabNetworkProfileArgsBuilder internal constructor() {
    private var loadBalancerId: Output<String>? = null

    private var publicIpId: Output<String>? = null

    private var subnetId: Output<String>? = null

    /**
     * @param value The external load balancer resource id
     */
    @JvmName("euvcnhcyalimvdjl")
    public suspend fun loadBalancerId(`value`: Output<String>) {
        this.loadBalancerId = value
    }

    /**
     * @param value The external public IP resource id
     */
    @JvmName("mvkmjlkljjjjnuxd")
    public suspend fun publicIpId(`value`: Output<String>) {
        this.publicIpId = value
    }

    /**
     * @param value The external subnet resource id
     */
    @JvmName("vpvxnmknytqunign")
    public suspend fun subnetId(`value`: Output<String>) {
        this.subnetId = value
    }

    /**
     * @param value The external load balancer resource id
     */
    @JvmName("ycxlcokwkoalqbjg")
    public suspend fun loadBalancerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadBalancerId = mapped
    }

    /**
     * @param value The external public IP resource id
     */
    @JvmName("hdxitoutkdissyyk")
    public suspend fun publicIpId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicIpId = mapped
    }

    /**
     * @param value The external subnet resource id
     */
    @JvmName("ritbponpwgpnsssn")
    public suspend fun subnetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnetId = mapped
    }

    internal fun build(): LabNetworkProfileArgs = LabNetworkProfileArgs(
        loadBalancerId = loadBalancerId,
        publicIpId = publicIpId,
        subnetId = subnetId,
    )
}
